/*
*********************************************************************************************************
*                                               uC/OS-II
*                                         The Real-Time Kernel
*
*                             (c) Copyright 1998-2005, Micrium, Weston, FL
*                                          All Rights Reserved
*
*
*                                            ARM Sample code
*
* File : APP.C
* By   : Jean J. Labrosse
*********************************************************************************************************
*/

#include "includes.h"

/*
*********************************************************************************************************
*                                                VARIABLES
*********************************************************************************************************
*/

OS_STK        AppStartTaskStk[APP_TASK_START_STK_SIZE];

#if OS_VIEW_MODULE > 0
static   OS_EVENT *Terminal_Mbox;              /* Mailbox to hold the value obtained from the terminal */
static   INT8U     View_Char;                  /* Character received from OS-View                      */
#endif


/*
*********************************************************************************************************
*                                            FUNCTION PROTOTYPES
*********************************************************************************************************
*/

static  void  AppStartTask(void *p_arg);

#if OS_VIEW_MODULE > 0
static  void  AppTerminalRx(INT8U rx_data);
#endif


/*
*********************************************************************************************************
*                                                main()
*
* Description : This is the standard entry point for C code.  It is assumed that your code will call
*               main() once you have performed all necessary CPU and C initialization.
* Arguments   : none
*********************************************************************************************************
*/

int main (void)
{
    INT8U  err;

    BSP_IntDisAll();						            /* Disable all interrupts  */

    OSInit();                               /* Initialize "uC/OS-II, The Real-Time Kernel"             */

    OSTaskCreateExt(AppStartTask,
                    (void *)0,
                    (OS_STK *)&AppStartTaskStk[APP_TASK_START_STK_SIZE - 1],
                    APP_TASK_START_PRIO,
                    APP_TASK_START_PRIO,
                    (OS_STK *)&AppStartTaskStk[0],
                    APP_TASK_START_STK_SIZE,
                    (void *)0,
                    OS_TASK_OPT_STK_CHK | OS_TASK_OPT_STK_CLR);

#if OS_TASK_NAME_SIZE > 11
    OSTaskNameSet(APP_TASK_START_PRIO, "Start Task", &err);
#endif

#if OS_TASK_NAME_SIZE > 14
    OSTaskNameSet(OS_IDLE_PRIO, "uC/OS-II Idle", &err);
#endif

#if (OS_TASK_NAME_SIZE > 14) && (OS_TASK_STAT_EN > 0)
    OSTaskNameSet(OS_STAT_PRIO, "uC/OS-II Stat", &err);
#endif

    OSStart();                              /* Start multitasking (i.e. give control to uC/OS-II)      */

    return (0);
}

/*
*********************************************************************************************************
*                                          STARTUP TASK
*
* Description : This is an example of a startup task.  As mentioned in the book's text, you MUST
*               initialize the ticker only once multitasking has started.
* Arguments   : p_arg   is the argument passed to 'AppStartTask()' by 'OSTaskCreate()'.
* Notes       : 1) The first line of code is used to prevent a compiler warning because 'p_arg' is not
*                  used.  The compiler should not generate any code for this statement.
*               2) Interrupts are enabled once the task start because the I-bit of the CCR register was
*                  set to 0 by 'OSTaskCreate()'.
*********************************************************************************************************
*/

static  void  AppStartTask (void *p_arg)
{
    INT8U  i;


    p_arg = p_arg;                       /* Prevent compiler warning                                   */

    BSP_Init();                          /* Initialize BSP functions                                   */

#if OS_TASK_STAT_EN > 0
    OSStatInit();                        /* Determine CPU capacity                                     */
#endif

#if OS_VIEW_MODULE > 0
    OSView_Init(19200);                  /* Initialize uC/OS-View                                      */
                                         /* Initialize the mailbox for the OS/View callback function   */
    Terminal_Mbox = OSMboxCreate((void *)0);
    OSView_TerminalRxSetCallback(AppTerminalRx);
#endif

    LED_Off(0);                          /* Turn OFF all the LEDs                                      */
    while (TRUE) {                       /* Task body, always written as an infinite loop.             */
        for (i = 1; i <= 4; i++) {
            LED_On(i);
            OSTimeDlyHMSM(0, 0, 0, 100);
            LED_Off(i);
        }
        for (i = 1; i <= 4; i++) {
            LED_On(5 - i);
            OSTimeDlyHMSM(0, 0, 0, 100);
            LED_Off(5 - i);
        }
    }
}


/*
*********************************************************************************************************
*                                      TERMINAL WINDOW CALLBACK
*********************************************************************************************************
*/

#if OS_VIEW_MODULE > 0
static  void  AppTerminalRx (INT8U rx_data)
{
    switch (rx_data) {
        case '0':
        case '1':
        case '2':
        case '3':
             View_Char = rx_data - '0';
             OSMboxPost(Terminal_Mbox, &View_Char);        /* Post the received character to a mailbox */
             break;
         default:
             break;
    }
}
#endif


/*** EOF ***/

