/*
*********************************************************************************************************
*                                               uC/OS-View
*
*                               (c) Copyright 2005, Micrium, Inc., Weston, FL
*                                           All Rights Reserved
*
*                                            STMicroelectronics
*                                                 STR711
*                                                 
* Filename  : OS_VIEWc.c
*
* Changes   : Michael Fischer
*             This port based on AN-1710.
*             I changed only a small part for the CrossWorks port.
*
* Toolchain : CrossWorks for ARM 1.5 Build 2 and higher
*********************************************************************************************************
*/

#include  <includes.h>

/*
*********************************************************************************************************
*                                           EXIT uC/OS-View
*
* Description: This function is not used in this port. 
*********************************************************************************************************
*/

void  OSView_Exit (void)
{

}

/*
*********************************************************************************************************
*                                           Obtain CPU name 
*
* Description: This routine allows the OSView application to display the name of the processor.
*********************************************************************************************************
*/

void  OSView_GetCPUName (INT8U *s)
{
    OS_StrCopy(s, "STR711");
}

/*
*********************************************************************************************************
*                                  Obtain Interrupt Stack Base
*
* Description: This function simply returns a zero
* Returns    : 0
*********************************************************************************************************
*/

INT32U  OSView_GetIntStkBase (void)
{
    return ((INT32U)0);                                         /* There is no seperate interrupt stack */
}

/*
*********************************************************************************************************
*                                  Obtain Interrupt Stack Size
*
* Description: This function simply returns a zero 
* Returns    : 0
*********************************************************************************************************
*/

INT32U  OSView_GetIntStkSize (void)
{
    return ((INT32U)0);                                         /* There is no seperate interrupt stack */
}

/*
*********************************************************************************************************
*                                    INITIALIZE uC/OS-View COM PORT
*
* Description: Initialize the hardware required for the OS to run. It is assumed that the timer has 
*              already been initialized by a BSP function. 
*********************************************************************************************************             
*/

void  OSView_InitTarget (INT32U baud_rate)
{
    OSView_TmrCntsPrev = 0;

    OSView_TmrInit();
    OSView_UARTInit(baud_rate);
}

/*
*********************************************************************************************************
*                                       Disable Rx Interrupts
*
* Description: Disable receive interrupts from the UART
*********************************************************************************************************
*/

void  OSView_RxIntDis (void) 
{
    UART0_IER &= (~0x0001);                          
}

/*
*********************************************************************************************************
*                                       Enable Rx Interrupts
*
* Description: Enable receive interrupts from the UART
*********************************************************************************************************
*/

void  OSView_RxIntEn (void) 
{
    UART0_IER |= 0x0001;
}

/*
*********************************************************************************************************
*                                 Rx Communication handler for uC/OS-View
*
* Description: This routine is not used because the UART produces a single interrupt for receives and 
*              transmits
*********************************************************************************************************
*/

void  OSView_RxISRHandler (void) 
{

}

/*
*********************************************************************************************************
*                                Rx/Tx Communication handler for uC/OS-View
*
* Description: This function is called whenever there is an interrupt from the UART
*********************************************************************************************************
*/

void  OSView_RxTxISRHandler (void) 
{
    INT8U   uart_chr;
    INT16U  uart_status;
    INT16U  int_en;
    
    uart_status = UART0_SR;                                   /* Read the UART's Status Register       */
    int_en      = UART0_IER;
    
    if ((uart_status & 0x0001) != 0x0000) {
        uart_chr = (INT8U)(UART0_RxBUFR & 0x00FF);
        OSView_RxHandler(uart_chr);                            /* Call the processor-independent code   */
        /* UART0_RxRSTR = 0xFFFF;  */                         /* Reset the fifo to clear the interrupt */
    }

    if (((uart_status & 0x0002) != 0x0000)&&((int_en & 0x0002) != 0)) {
        OSView_TxHandler();                                    /* Call the processor-independent code   */
        UART0_GTR = 0x0080;                                   /* Reset the UART's Guard time           */
        /* UART0_TxRSTR = 0xFFFF;  */                         /* Reset the fifo to clear the interrupt */
    }
 
    if ((uart_status & 0x0080) != 0x0000) {
        UART0_TOR = 0x00FF;
    }
}

/*$PAGE*/
/*
*********************************************************************************************************
*                                      Transmit a Character
*
* Description: Send 1 character to COM Port
*********************************************************************************************************
*/

void  OSView_Tx1 (INT8U c) 
{ 
    UART0_TxBUFR = (INT16U) c;                                /* Place the character in the TX buffer */
}

/*
*********************************************************************************************************
*                                       Disable Tx Interrupts
*
* Description: This routine disables transmit interrupts from the UART
*********************************************************************************************************
*/

void  OSView_TxIntDis (void) 
{
    UART0_IER &= (~0x0002);
}

/*
*********************************************************************************************************
*                                       Enable Tx Interrupts
*
* Description: This routine enables transmit interrupts from the UART
*********************************************************************************************************
*/

void  OSView_TxIntEn (void) 
{
    UART0_IER |= 0x0002; 
}


/*
*********************************************************************************************************
*                                 Tx Communication handler for uC/OS-View
*
* Description: This routine is not used because the UART produces a single interrupt for receives and 
*              transmits
*********************************************************************************************************
*/

void  OSView_TxISRHandler (void) 
{

}

/*** EOF ***/














